import React, { useState, useEffect } from 'react';
import { Form, Icon, Input, Button, DatePicker, Select, Card, Row, Col, Pagination, Alert, Table, Avatar, Radio, Modal, Descriptions } from 'antd';
import moment from 'moment';
import request from '../../../utils/request';
import apis from '../../../services/apis';
import router from 'umi/router';
import BuildSelect from '../../../components/SelectButton/BuildSelect'
import AuthButton from '@/components/AuthButton';


const { Option } = Select;
// eslint-disable-next-line @typescript-eslint/no-unused-vars
const { Meta } = Card;

/**
 *
 *
 * @param {*} props
 * @returns
 */
function body(props) {
  const { getFieldDecorator, getFieldsValue } = props.form

  // eslint-disable-next-line react-hooks/rules-of-hooks
  const [dataSource, setDataSource] = useState({ records: [] })
  // eslint-disable-next-line react-hooks/rules-of-hooks
  // const [columns, setColumns] = useState(privateColumns)

  // 默认私客
  // eslint-disable-next-line react-hooks/rules-of-hooks
  const [customerType, setCustomerType] = useState('helpSucceed')

  // 调整归属 ============  start
  // eslint-disable-next-line react-hooks/rules-of-hooks
  const [gVisibleData, setGVisibleData] = useState({ visible: false, customerId: '', realtyConsultant: '' })
  // 调整归属 ============= end

  // 积分记录 ============  start
  // eslint-disable-next-line react-hooks/rules-of-hooks
  const [recordVisibleData, setRecordVisibleData] = useState({ visible: false, customerId: '' })
  // 积分记录 ============= end

  // 变更状态 ============  start
  // eslint-disable-next-line react-hooks/rules-of-hooks
  const [statusVisibleData, setStatusVisibleData] = useState({ visible: false, customerId: '', status: '' })
  // 变更状态 ============= end

  // eslint-disable-next-line react-hooks/rules-of-hooks
  const { helpActivityId } = props.location.query
  useEffect(() => {
    console.log('customerType', customerType)
    getList({ pageNumber: 1, pageSize: 10, status: customerType, helpActivityId })
  }, [])

  function getList(params) {
    // 网路请求
    request({ ...apis.helpActivity.record, params: { ...params } }).then(res => {
      setDataSource(res)
    }).catch(err => {
      // eslint-disable-next-line no-unused-expressions
      <Alert
        style={{
          marginBottom: 24,
        }}
        message={err}
        type="error"
        showIcon
      />
    })
  }

  function displayNone() {
    setRecordVisibleData({ visible: false, customerId: '' })
    setGVisibleData({ visible: false, customerId: '', realtyConsultant: '' })
    setStatusVisibleData({ visible: false, customerId: '', status: '' })
  }

  // 提交事件
  function handleSubmit(e) {
    displayNone()


    e.preventDefault();
    props.form.validateFields((err, values) => {
      if (!err) {
        getList({ pageNum: 1, pageSize: 10, customerType, ...values })
      }
    });
  }

  // Change 事件
  function handleSelectChange(e) {
    // eslint-disable-next-line no-console
    console.log(e)
  }

  // 分页
  function onChange(pageNum) {
    // eslint-disable-next-line react-hooks/rules-of-hooks
    getList({ pageNumber: pageNum, pageSize: 10, customerType })
  }

  // 私客/公客切换
  function radioButtonHandleSizeChange(e) {
    displayNone()

    const { value } = e.target
    setCustomerType(value)
    // setColumns(value === 'helpSucceed' ? privateColumns : publicColumns)
    getList({ pageNumber: 1, pageSize: 10, status: value, helpActivityId })
  }

  function handleReset() {
    props.form.resetFields();
    getList({ pageNumber: 1, pageSize: 10, customerType })
  }


  // 这里有个 Bug， 就是 Modal 弹框，会联动出现， 比如 我点击 调整归属的Model弹框， 那么 积分记录的Model弹框莫名其妙的也显示了
  // 所有这里临时解决方法是，弹出一个Modal对话框的时候，把其他的对话框给隐藏

  function showGM(record) {
    setGVisibleData({ visible: true, customerId: record.customerId, realtyConsultant: record.realtyConsultant })
    setRecordVisibleData({ visible: false, customerId: '' })
    setStatusVisibleData({ visible: false, customerId: '' })
  }

  function showRecord(record) {
    setRecordVisibleData({ visible: true, customerId: record.customerId })
    setGVisibleData({ visible: false, customerId: '', realtyConsultant: '' })
    setStatusVisibleData({ visible: false, customerId: '' })
  }

  function showStatus(record) {
    setRecordVisibleData({ visible: false, customerId: '' })
    setGVisibleData({ visible: false, customerId: '', realtyConsultant: '' })
    setStatusVisibleData({ visible: true, customerId: record.customerId, status: record.status })
  }
  function toCustomerDateil(record) {
    router.push({
      pathname: '/customer/customerlist/customerDetail',
      query: {
        id: record.customerId,
      },
    });
  }

  function exportCustomer () {
    const fieldsValue = getFieldsValue()
    request({ ...apis.customer.customerRecommendExport, responseType: 'blob', params: { ...fieldsValue, customerType } })
      .then(response => {
        download(response)
      }).catch(error => {

      })
  }

  function download (data) {
    if (!data) {
      return
    }
    const url = window.URL.createObjectURL(new Blob([data]))
    const link = document.createElement('a')
    link.style.display = 'none'
    link.href = url
    link.setAttribute('download', '客户列表.xlsx')
    document.body.append(link)
    link.click()
  }

  const publicColumns = [
    {
      title: '发起者',
      dataIndex: 'name',
      key: 'name',
      align: 'center',
      width: '15%',
    },
    {
      title: '发起者手机号',
      dataIndex: 'phone',
      key: 'phone',
      align: 'center',
      width: '10%',
    },
    {
      title: '发起时间',
      dataIndex: 'createDate',
      key: 'createDate',
      align: 'center',
      width: '15%',
    },
    {
      title: '助力者',
      dataIndex: 'helpCount',
      key: 'helpCount',
      align: 'center',
      width: '15%',
      render: (text, record) => <a style={ { color: '#66B3FF' } } >{record.helpCount}/{record.persionNumCount}</a>,
    },
  ]

  const privateColumns = [
    {
      title: '发起者',
      dataIndex: 'name',
      key: 'name',
      align: 'center',
      width: '15%',
      // render: (_, record) => <Avatar shape="square" src={customerType === 'helpSucceed' ? record.picture : record.avatarurl} size={64} icon="user" />,
    },
    {
      title: '手机号',
      dataIndex: 'phone',
      key: 'phone',
      align: 'center',
      width: '10%',
      // eslint-disable-next-line no-nested-ternary
      // render: (_, record) => <><span>{customerType === 'helpSucceed' ? record.name : record.nickname}</span></>,
    },
    {
      title: '发起时间',
      dataIndex: 'createDate',
      key: 'createDate',
      align: 'center',
      width: '10%',
      // eslint-disable-next-line no-nested-ternary
    },
    {
      title: '助力者',
      dataIndex: 'helpCount',
      key: 'helpCount',
      align: 'center',
      width: '15%',
      render: (text, record) => <a style={ { color: '#66B3FF' } } >{record.helpCount}人</a>,
    },
    {
      title: '核销状态',
      dataIndex: 'reportRecommendStatus',
      key: 'reportRecommendStatus',
      align: 'center',
      width: '10%',
      // eslint-disable-next-line no-nested-ternary
      render: (text, records) => {
        if (records.verificationStatus === 0) { return '未核销' }
        if (records.verificationStatus === 1) { return '已核销' }
      },
    },
    {
      title: '操作',
      dataIndex: 'customerId',
      key: 'customerId',
      align: 'center',
      width: '25%',
      render: (x, row) => (
        <>
          {row.verificationStatus === 0 &&
          <AuthButton name="admin.SignList.get" noRight={null}>
           <span style={{ color: '#1990FF', cursor: 'pointer' }}>核销</span>
          </AuthButton>
        }
        </>
      ),
    },
  ]

  return (
    <>
    {console.log('customerType', customerType)}
      <Form layout="inline" onSubmit={e => handleSubmit(e, props)}>
        <Form.Item>
          {getFieldDecorator('tel')(
            <Input
              prefix={<Icon type="text" style={{ color: 'rgba(0,0,0,.25)' }} />}
              placeholder="电话"
            />,
          )}
        </Form.Item>
        <Form.Item>
            <Button type="primary" htmlType="submit" >
              查询
            </Button>
            <Button style={{ marginLeft: 8 }} onClick={handleReset}>
              重置
            </Button>
            <Button style={{ marginLeft: 8 }} onClick={handleReset}>
              返回
            </Button>
        </Form.Item>
      </Form>
      <Button type="primary" onClick={() => exportCustomer()} style={{ float: 'right', margin: '20px 0', zIndex: 1 }}>
        导出
      </Button>

      <div style={{ margin: '20px 0' }}>
        <AuthButton name="admin.customer.recommend.get" noRight={null}>
          <Radio.Group value={customerType} onChange={radioButtonHandleSizeChange} buttonStyle="solid">
            <Radio.Button value="helpSucceed">助力成功</Radio.Button>
            <Radio.Button value="helpUnderway">进行中</Radio.Button>
            <Radio.Button value="helpUnfinished ">助力失败</Radio.Button>
          </Radio.Group>
        </AuthButton>
      </div>
      {customerType === 'helpSucceed' ?
        <Table dataSource={dataSource.list} columns={privateColumns} pagination={{ total: dataSource.total, onChange }} rowKey="customerList" /> :
        <Table dataSource={dataSource.list} columns={publicColumns} pagination={{ total: dataSource.total, onChange }} rowKey="customerList" /> 
      }
    </>
  );
}

const WrappedBody = Form.create({ name: 'body' })(body);

export default WrappedBody
